@@ -11,9 +11,8 @@ fi
 make clean 
 make -f drawConfig.mk
 mkdir -p $work
+source setarch.sh
 fullpath=$1
+echo config path is $fullpath
 echo $1 > $work/.configrc
-./drawconfig
-
-
-
+./drawconfig$ARCH   $fullpath
