@@ -10,19 +10,21 @@ program main
   use modDCS
   use modcTPXS
   implicit none
-
+ 
   real(8)::cm2pgrm
   integer:: nmuc, nec, j
   integer:: io=11
 
 !  write(0,*) 'Enter T to print reduced pdf '
 !  read(*,*) print_redpdf
+  character(len=8):: dummy
+  
+  read(*,*) c1forHardScat, maxHCSmfprl, print_redpdf
 
-  open(io,file="paramdata")
-  read(io,*) c1forHardScat, maxHCSmfprl, print_redpdf
-  close(io)
+  write(0,*) ' p   ..',c1forHardScat, maxHCSmfprl, print_redpdf
 
   call readMedia
+  
   call epiniXsMedia
   cm2pgrm =  media(1)%mbtoPkgrm/ 1d-27 *10.0
   write(0,*) ' cm2pgram2=', cm2pgrm
@@ -31,13 +33,13 @@ program main
   write(0,*) ' print_redpdf =', print_redpdf
 
   j = 1
-
   call ciniSmpTab
   call csetSmpTblconst
 !   
   write(*,'(f7.4, g12.4,a,a)')  &
-  c1forHardScat,  maxHCSmfprl, ' c1forHardScat  maxHCSmfprl------- '
+       c1forHardScat,  maxHCSmfprl, ' c1forHardScat  maxHCSmfprl------- '
+  
   call cmkSmpTab(DCSnega(j), TPXSnega(j), "e-")
-
   call cmkSmpTab(DCSposi(j), TPXSposi(j), "e+")
 end program main
+  
