@@ -2,10 +2,10 @@
       implicit none
 #include "Zmedia.h"
 #include "Zmass.h"
-c        
-c          test muon pair creation sampling 
-c
-      record /epmedia/media
+!        
+!          test muon pair creation sampling 
+!
+       type(epmedia):: media
       integer i, io, icon, norm, nevent, dummy, seed(2)
       real*8 Emu, prob, Et, path, normf
       real*8 epmuPairVmn
@@ -35,10 +35,10 @@ c
       call  cmkSeed(dummy, seed)
       call rnd1i(seed)
 
-      xmin = max( media.cnst.muPrVmin, epmuPairVmn(Emu))
-c////////////
-c      xmin = epmuPairVmn(Emu)  ! this is to see entire function region
-c/////////////
+      xmin = max( media%cnst%muPrVmin, epmuPairVmn(Emu))
+!////////////
+!      xmin = epmuPairVmn(Emu)  ! this is to see entire function region
+!/////////////
       write(0,'(a)')
      *   '# "E_pair/Emu" "log10(E_pair/Emu)" "sampled path(r.l)" '//
      *   ' " prob/r.l" "Emu'    
