@@ -433,9 +433,10 @@ function epDirecPairInteDxsOrg(E) result(ans)
      write(0,*) 'sc=', sc, ' ng for  epDirecPairInteDxs(E)'
      stop
   endif
-  if( NormDpXs ) then
-     ans = epDirecPadjf()*ans
-  endif
+!!!       NormDpXs  should not be   applied. May 17/2020
+!!!  if( NormDpXs ) then
+!!!     ans = epDirecPadjf()*ans
+!!!  endif
 end function epDirecPairInteDxsOrg
 
 
