@@ -1,4 +1,4 @@
-c             gaussian density beam
+!             gaussian density beam
        subroutine epGaussb(hwhm, rcut, x, y)
        implicit none
        real*8 hwhm  ! input. half width at half max (cm)
@@ -7,12 +7,12 @@ c             gaussian density beam
 
        real*8 alg2, a, tmp, ome, u, r, cs, sn, omu
        
-c               ln(2)
+!               ln(2)
            data alg2/.69314718/
-c             density is: f(r)=* exp(-(r/rh)**2 * ln(2))
-c             distribution is f(r)*r*dr where rh is half
-c             width at half
-c             max of f(r) = hwhm
+!             density is: f(r)=* exp(-(r/rh)**2 * ln(2))
+!             distribution is f(r)*r*dr where rh is half
+!             width at half
+!             max of f(r) = hwhm
            a=alg2/hwhm**2
            tmp=a* rcut**2
            if(tmp .lt. 1.e-4) then
@@ -28,31 +28,31 @@ c             max of f(r) = hwhm
                 omu=log(1. - tmp)
            endif
            r=sqrt(-omu/a)
-c             sample (x,y)
+!             sample (x,y)
            call kcossn(cs,sn)
            x=r*cs
            y=r*sn
        end
-c     *********************************************************
+!     *********************************************************
       subroutine epgonSphere(ini, hwhm, rin, teta, phi, oa, pos)
       implicit none
 #include "ZepTrackp.h"
 #include "ZepPos.h"     
 #include "Zptcl.h"
 #include "Zglobalc.h"
-c            generate a random point distributed on the
-c            surface of a sphere with a Gaussian density.(Note below)
-c            Points are distributed around
-c            given polar angles (teta, phi) within a given opening angle
-c            (oa).  
+!            generate a random point distributed on the
+!            surface of a sphere with a Gaussian density.(Note below)
+!            Points are distributed around
+!            given polar angles (teta, phi) within a given opening angle
+!            (oa).  
 
-c Note:   Gaussian means that the beam has a Gaussian density if it is
-c    projected to the plane which is tangent to the sphere at the
-c    Gaussian center.
-c    The rcut used for epGaussb is related to oa here as
-c    rcut = r sin( oa ).
-c ****** If hwhm is negative, uniform distribution is assumed instead of Gauss.
-c
+! Note:   Gaussian means that the beam has a Gaussian density if it is
+!    projected to the plane which is tangent to the sphere at the
+!    Gaussian center.
+!    The rcut used for epGaussb is related to oa here as
+!    rcut = r sin( oa ).
+! ****** If hwhm is negative, uniform distribution is assumed instead of Gauss.
+!
       integer ini               ! input
                       !  1-->  teta and phi are different from
                       !        previous call or this is the first call.
@@ -65,10 +65,11 @@ c
       real*8  teta      ! input.  polar angle in degree
       real*8  phi       ! input.  azimutal angle in degree
       real*8  oa        ! input.  opnening angle in degree. has meaning
-                        !         if os <= 90.
-      record /epPos/ pos  ! output. an  obtained random point
+!         if os <= 90.
+      real(8),intent(out):: origpos(3)
+       type(epPos)::  pos  ! output. an  obtained random point
 
-      record /fmom/ xyz, xyz2
+       type(fmom),save::  xyz, xyz2
       real*8  a(4, 4), b(4, 4), ba(4, 4)
 
       real*8  rcut, x, y, z, z2, r, temp, u, fsin, fcos
@@ -97,32 +98,36 @@ c
          y = temp * fsin 
          z =  sqrt(r**2 - x**2-y**2)
       endif
-      xyz.p(1) = x
-      xyz.p(2) = y
-      xyz.p(3) = z
-      xyz.p(4) = 1.
+      xyz%p(1) = x
+      xyz%p(2) = y
+      xyz%p(3) = z
+      xyz%p(4) = 1.
       call capplyRot4(ba, xyz, xyz2)
-      pos.x = xyz2.p(1)
-      pos.y = xyz2.p(2)
-      pos.z = xyz2.p(3)
+      pos%x = xyz2%p(1)
+      pos%y = xyz2%p(2)
+      pos%z = xyz2%p(3)
+      return
+!!!
+      entry epgonSphere2(origpos)
+      origpos(1:3) = xyz%p(1:3)
       end
-c     **************************************************
+!     **************************************************
       subroutine epuonSphere(ini, rin, teta, phi, oa, pos)
       implicit none
 #include "ZepTrackp.h"
 #include "ZepPos.h"     
 #include "Zptcl.h"
 #include "Zglobalc.h"
-c          generate a random point uniformly distributed on the
-c          surface of a sphere.  Points are distributed around
-c          given polar angles (teta, phi) within a given opening angle
-c          (oa). (Actually, the point is put little bit inside of
-c          the sphere by an amount of EpsLeng so that it can be
-c          judged on or inside the sphere safely even with some
-c          numerical error). 
-c    By uniform  is meant that the points are uniformly distributed on
-c    the surface of the sphere but not on a projected plane.
-c
+!          generate a random point uniformly distributed on the
+!          surface of a sphere.  Points are distributed around
+!          given polar angles (teta, phi) within a given opening angle
+!          (oa). (Actually, the point is put little bit inside of
+!          the sphere by an amount of EpsLeng so that it can be
+!          judged on or inside the sphere safely even with some
+!          numerical error). 
+!    By uniform  is meant that the points are uniformly distributed on
+!    the surface of the sphere but not on a projected plane.
+!
       integer ini               ! input
                       !  1-->  teta and phi are different from
                       !        previous call or this is the first call.
@@ -132,9 +137,9 @@ c
       real*8  teta              ! input.  polar angle in degree
       real*8  phi               ! input.  azimutal angle in degree
       real*8  oa                ! input.  opnening angle in degree
-      record /epPos/ pos        ! output. an  obtained random point
+       type(epPos)::  pos        ! output. an  obtained random point
 
-      record /fmom/ xyz, xyz2
+       type(fmom)::  xyz, xyz2
       real*8  a(4, 4), b(4, 4), ba(4, 4)
       real*8  u, r
       real*8 fcos,  fsin
@@ -153,37 +158,37 @@ c
       fsin = sqrt(1.d0- fcos**2)
       call rndc(u)
       u = u*pi*2
-      xyz.p(1) = r * (fsin * cos(u))
-      xyz.p(2) = r * (fsin * sin(u))
-      xyz.p(3) = r * fcos 
-      xyz.p(4) = 1.
+      xyz%p(1) = r * (fsin * cos(u))
+      xyz%p(2) = r * (fsin * sin(u))
+      xyz%p(3) = r * fcos 
+      xyz%p(4) = 1.
       call capplyRot4(ba, xyz, xyz2)
-      pos.x = xyz2.p(1)
-      pos.y = xyz2.p(2)
-      pos.z = xyz2.p(3)
+      pos%x = xyz2%p(1)
+      pos%y = xyz2%p(2)
+      pos%z = xyz2%p(3)
       end
       subroutine epuSphere(rin, dir,  pos)
       implicit none
 #include "ZepTrackp.h"
 #include "ZepDirec.h"
 #include "ZepPos.h"     
-c#include "Zptcl.h"
-c#include "Zglobalc.h"
-c          Note  diff. from epuonSphere
-c          This one will
-c          generates a random point on the  surface of a sphere.
-c          Points are distributed on the projected plane (area is
-c          pixR^2 where R is the radius of the sphere)
-c          which is defined as a pependicular plane to the given
-c          direction given by dir.  The position returned to the user
-c          is little bit inside the sphere by an amount of EpsLeng.
-c
+!#include "Zptcl.h"
+!#include "Zglobalc.h"
+!          Note  diff. from epuonSphere
+!          This one will
+!          generates a random point on the  surface of a sphere.
+!          Points are distributed on the projected plane (area is
+!          pixR^2 where R is the radius of the sphere)
+!          which is defined as a pependicular plane to the given
+!          direction given by dir.  The position returned to the user
+!          is little bit inside the sphere by an amount of EpsLeng.
+!
 
       real*8  rin               ! input.  radius of the sphere
-c                                 sphere center is assumed to be at the origin.
-      record /epDirec/ dir        ! input.  direction cosine
-      record /epPos/ pos        ! output. an  obtained random point
-      record /epPos/ xyz
+!                                 sphere center is assumed to be at the origin.
+       type(epDirec)::  dir        ! input.  direction cosine
+       type(epPos)::  pos        ! output. an  obtained random point
+       type(epPos)::  xyz
       real*8 fcos,  fsin, r, u
 
 
@@ -191,12 +196,12 @@ c                                 sphere center is assumed to be at the origin.
 
       call kcossn(fcos, fsin)
       call rndc(u)
-      xyz.x = r *  sqrt(u)
-      xyz.y = xyz.x * fsin 
-      xyz.x = xyz.x * fcos
-      xyz.z = r * sqrt(1.d0 -  u) 
-      if(dir.z .gt. 0.) then 
-         xyz.z= -xyz.z
+      xyz%x = r *  sqrt(u)
+      xyz%y = xyz%x * fsin 
+      xyz%x = xyz%x * fcos
+      xyz%z = r * sqrt(1.d0 -  u) 
+      if(dir%z .gt. 0.) then 
+         xyz%z= -xyz%z
       endif
       call ctransVectZ(dir, xyz, pos)
       end
@@ -206,7 +211,7 @@ c                                 sphere center is assumed to be at the origin.
        implicit none
        integer io
           character* 10  sep
-c             *** until loop*** 
+!             *** until loop*** 
              do while (.true.)
                read(io, '(a)') sep
              if         (sep .eq. '----------')
@@ -214,7 +219,7 @@ c             *** until loop***
              enddo
    10        continue
        end
-c        ************************* real*8 data
+!        ************************* real*8 data
        subroutine arprmr(vvalue, x)
         implicit none
         integer io
@@ -231,13 +236,13 @@ c        ************************* real*8 data
         read(vvalue, *)   x, x
         end
 
-c     *******************************
+!     *******************************
       subroutine epgetdatline(io, dat, j)
       implicit none
       integer io  ! input. read device logical number
       character*120  dat  ! output. data line
-c       null lines or the lines which have two or more blank characters
-c       at head is neglected
+!       null lines or the lines which have two or more blank characters
+!       at head is neglected
       integer j  ! input/output input. 0--> If  EOF,stop
                  !                     1--> If  Eof, 2 is returned.
                  !                          if not eof, 1 is unchanged   
@@ -249,7 +254,7 @@ c       at head is neglected
       do while ( dat(1:2) .eq. '  ' .or. dat(1:1) .eq. tab) 
          read(io, '(a)', end=80) dat
       enddo
-c         check if "/" exists for safety
+!         check if "/" exists for safety
       if( index(dat, "/") .eq. 0 .and. j .eq. 0 ) then
          call cerrorMsg(dat, 1)
          call cerrorMsg(' has no "/" in the data line', 0)
@@ -266,35 +271,37 @@ c         check if "/" exists for safety
       endif
          
       end   
-c     ************************* complex data
+!     ************************* complex data
       subroutine arprmm(vvalue, c)
       implicit none
       character*(*) vvalue
-      complex*16 c
+      complex(8):: c
+
+       
       read( vvalue, *)   c, c
       end
-c     ************************ integer data
+!     ************************ integer data
       subroutine arprmi(vvalue, i)
       implicit none
       character*(*) vvalue
       integer i
       read(vvalue, *)   i,i
       end
-c        ************************* character data
+!        ************************* character data
       subroutine arprmc(vvalue, cha)
       implicit none
       character*(*) vvalue
       character*(*) cha
       read(vvalue, *)  cha, cha
       end
-c        ***************************** logical data
+!        ***************************** logical data
       subroutine arprml(vvalue, logi)
       implicit none
       character*(*) vvalue
       logical logi
       read(vvalue, *)  logi, logi
       end     
-c        ---------------------------------------------
+!        ---------------------------------------------
       subroutine awprmr(io, vname, x)
       implicit none
       integer io
@@ -325,7 +332,7 @@ c        ---------------------------------------------
       implicit none
       integer io
       character*(*) vname
-      complex*16  c
+      complex(8)::  c
       write(io,  *) ' ', vname,' ', c,' /'
       end
       subroutine awprmi(io, vname, i)
@@ -360,9 +367,9 @@ c        ---------------------------------------------
       end
       subroutine anamec(vn, dt)
       implicit none
-c      
-c            check variable name
-c
+!      
+!            check variable name
+!
       character*(*) vn, dt
       character*90 msg
       if(vn .ne.  dt) then
@@ -371,7 +378,7 @@ c
          call cerrorMsg(msg, 0)
       endif
       end
-c      ********************
+!      ********************
       subroutine epqHookc(i, cv)
       implicit none
 #include "ZepManager.h"
@@ -380,7 +387,7 @@ c      ********************
 
       integer klena
       if(i .le.  0 .or. i .gt. epHooks(1))  then
-c         call cerrorMsg('out of range request to epqHookc',2)
+!         call cerrorMsg('out of range request to epqHookc',2)
          cv = ' '
       else
          cv = epHookc(i)(1:klena(epHookc(i)))
@@ -395,7 +402,7 @@ c         call cerrorMsg('out of range request to epqHookc',2)
 
 
       if(i .le.  0 .or. i .gt. epHooks(2))  then
-c         call cerrorMsg('out of range request to epqHooki',0)
+!         call cerrorMsg('out of range request to epqHooki',0)
          iv = -9999999
       else
          iv = epHooki(i)
@@ -411,14 +418,14 @@ c         call cerrorMsg('out of range request to epqHooki',0)
 
 
       if(i .le.  0 .or. i .gt. epHooks(3))  then
-c         call cerrorMsg('out of range request to epqHookr',0)
+!         call cerrorMsg('out of range request to epqHookr',0)
          rv = -1.d-60
       else
          rv = epHookr(i)
       endif
       end
       logical function epgetParmN( io,  vname, vv )
-c          get parameter variable name and given value(s)  from io
+!          get parameter variable name and given value(s)  from io
       implicit none
        integer io
        character*(*)  vname, vv  ! output
