@@ -1,10 +1,15 @@
-       subroutine epprmr(dsn)
-       implicit none
+      subroutine epprmr(dsn)
+      use modV1ry
+      use SampMolReducedA
+      use modMCSparam
+      use modDirecPair,only: DirecPair, BareTarget, AdjFac, NormDpXs,
+     *    HowTargetZ, piKDp
+      implicit none
 #include  "ZepTrackp.h"
 #include  "ZepManager.h"
-c
-c             read epics file
-c
+!
+!             read epics file
+!
             character*(*) dsn
             integer io,  icon, klena, i
             character*190 msg
@@ -22,7 +27,7 @@ c
                call cerrorMsg('above file not exits', 1)
             endif
 
-c            read baisc parameters; find separater
+!            read baisc parameters; find separater
             call afsep(iowk)
             do while( epgetParmN(iowk, vname, vvalue ) )
                if(vname .eq. 'AngleB') then
@@ -51,6 +56,8 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, EminH)
                elseif( vname .eq. 'Es' ) then
                   call arprmr(vvalue, Escat)
+               elseif( vname == 'Zcorrec') then
+                  call arprml(vvalue, Zcorrec)
                elseif( vname .eq. 'EupperBndCS') then
                   call arprmr(vvalue, EupperBndCS)
                elseif( vname .eq. 'EpartialSC') then
@@ -92,13 +99,14 @@ c            read baisc parameters; find separater
                elseif( vname .eq. 'IncGp') then
                   write(0,*) 'Sorry: IncGp is managed by param file'
                   write(0,*) 
-     *       'If needed, use HowPhotoP(D=4)in &HPARAM part of param'
+     *       'If needed, use HowPhotoP(D=1)in &HPARAM part of param'
                   stop
                elseif( vname .eq. 'IoTrace') then
                   call arprmi(vvalue, IoTrace)
                elseif( vname .eq. 'Knckon' ) then
                   call arprml(vvalue, Knckon)
-               elseif( vname .eq. 'Molier' ) then
+               elseif( vname .eq. 'Molier' .or.
+     *                 vname == 'Moliere'  ) then  ! v9.170
                   call arprmc(vvalue, msg)
                   if( msg == 't' .or. msg == 'T') then
                      Moliere = 1
@@ -107,6 +115,76 @@ c            read baisc parameters; find separater
                   else
                      call arprmi(vvalue, Moliere)
                   endif
+                  !!!!!!!!!!Next 34 are for the direct pair creation
+               elseif( vname == 'DirecPair' ) then
+                  call arprml(vvalue, DirecPair)
+               elseif( vname == 'BareTarget' ) then
+                  call arprml(vvalue, BareTarget) 
+               elseif( vname == 'AdjFac' ) then
+                  call arprmr(vvalue, AdjFac )
+               elseif( vname == 'NormDpXs' ) then
+                  call arprml(vvalue, NormDpXs )
+               elseif( vname == 'HowTargetZ' ) then
+                  call arprmi(vvalue, HowTargetZ )
+               elseif( vname == 'piKDp' ) then
+                  call arprmi(vvalue, piKDp )
+                  !!!!!!!!!
+               elseif( vname == 'MCSmodel' ) then
+                  call arprmc(vvalue, MCSmodel)
+               elseif( vname == 'MCSdir' ) then
+                  call arprmc(vvalue, MCSdir)
+               elseif( vname == 'MCSparam' ) then
+                  call arprmc(vvalue, MCSparam)
+!                  MCSparam will be read  by
+!     Cosmos/Particle/Event/Elemag/MixedMCS/Sampling/cMCSconstForMedia.f
+!             elseif( vname == 'MCSxRange' ) then
+!                  if(MCSxCond < MCSxyzCondmx) then
+!                     MCSxCond = MCSxCond+1
+!                     call arprmm(vvalue, MCSxRange(MCSxCond))
+!                  else
+!                     write(0,*) ' too many MCSxRange'
+!                     stop
+!                  endif
+                  
+!                  if(MCSyCond < MCSxyzCondmx) then
+!                     MCSyCond = MCSyCond+1
+!                     call arprmm(vvalue, MCSyRange(MCSyCond))
+!                  else
+!                     write(0,*) ' too many MCSyRange'
+!                     stop
+!                  endif
+               elseif( vname == 'MCSzRange' ) then
+                  if(MCSzCond < MCSxyzCondmx) then
+                     MCSzCond = MCSzCond+1
+                     call arprmm(vvalue, MCSzRange(MCSzCond))
+                  else
+                     write(0,*) ' too many MCSzRange'
+                     stop
+                  endif
+                  
+               elseif( vname == 'MCSnumRange' ) then
+                  if(MCSnumCond < MCSnumCondmx) then
+                     MCSnumCond = MCSnumCond+1
+                     call arprmm(vvalue, MCSnumRange(MCSnumCond))
+                  else
+                     write(0,*) ' too many MCSnumRange'
+                     stop
+                  endif
+               elseif( vname == 'MCSandor' ) then
+                  call arprmc(vvalue, MCSandor )
+                  if( MCSandor /= 'and' .and. MCSandor /= 'or' ) then
+                     write(0,*) ' MCSandor value =',MCSandor
+                     write(0,*) ' invalid. '
+                     stop
+                  endif
+               elseif( vname == 'MCSrevert' ) then
+                  call arprml(vvalue, MCSrevert)
+               elseif( vname == 'MCSdebug' ) then
+                  call arprml(vvalue, MCSdebug)
+               elseif( vname == 'sbMin' ) then ! v9.201;don't use
+                  write(0,*)
+     *            'NOTE****: sbMin in epicsfile obsolete; not used'
+!                  call arprmr(vvalue, sbMin)
                elseif( vname .eq. 'Photo') then
                   call arprml(vvalue, Photo)
                elseif( vname .eq. 'RecoilKeMin') then
@@ -139,6 +217,8 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, Ezu)
                elseif( vname .eq. 'FreeC' ) then
                   call arprml(vvalue, FreeC)
+               elseif( vname == "FollowV1ry") then
+                  call arprml(vvalue, FollowV1ry)
                elseif( vname .eq. 'EpsLeng') then
                   call arprmr(vvalue, EpsLengX)
                   if(EpsLengX < 0. ) then
@@ -205,7 +285,7 @@ c            read baisc parameters; find separater
      *      dsn(1:klena(dsn))
             call cerrorMsg(msg, 1)
             return
-c      *************
+!      *************
        entry epprmw(io)
             write(io,*)'----------------------'
             call awprml(io,'AngleB', AngleB)
@@ -221,6 +301,7 @@ c      *************
             call awprmc(io, 'ModifyFile', ModifyFile)
             call awprmr(io,'EminH', EminH)
             call awprmr(io,'Es   ', Escat)
+            call awprml(io,'Zcorrec', Zcorrec)
             call awprmr(io,'EupperBndCS ', EupperBndCS)
             call awprmr(io,'EpartialSC ', EpartialSC)
             call awprmi(io,'TargetElecBrems', TargetElecBrems)
@@ -260,26 +341,33 @@ c      *************
             call awprmc(io, 'TraceDir', TraceDir)
 
       end
-c      ************
+!      ************
        subroutine  epcmp1
-c      ************
+!      ************
        use epModify
+       use SampMolReducedA
        implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
 #include "ZepManager.h"
 #include "Zmass.h"
-c             compute something using basic parameters
-c
+!             compute something using basic parameters
+!              v 9.201
+       if( sbMin == 0. .and. Moliere == 1 ) then
+          sbMin=3.395d0
+       elseif(sbMin == 0. .and. Moliere == 2 ) then
+          sbMin=1.5d0
+       endif
+
        if(ALateCor .eq. 2 .or.
      *        ( ALateCor .eq. 1 .and.  Moliere == 0)) then
-c          angular latelaral correlation will be taken at
-c          multiple scattering. use standard trucation
+!          angular latelaral correlation will be taken at
+!          multiple scattering. use standard trucation
           Tcoefx = Tcoef
           Tminx = Tmin
        else
-c            no correlation will be considered so make
-c          truncation length shorter
+!            no correlation will be considered so make
+!          truncation length shorter
           Tcoefx = Tcoef/2
           Tminx = Tmin/2
        endif
@@ -295,7 +383,7 @@ c          truncation length shorter
        if( RecoilKEmin .eq. 0.) then
           RecoilKEmin =EminElec - masele
        endif
-c           save;  to be used in epModify;  in GeV
+!           save;  to be used in epModify;  in GeV
        EminGsave = EminGamma
        EminEsave = EminElec
        RecoilEsave = RecoilKEmin
@@ -307,7 +395,7 @@ c           save;  to be used in epModify;  in GeV
        if( ModifyFile /= " " ) then  ! special modification requested
           call epfixModifier(ModifyFile)
        endif
-c        get info from  Cosmos
+!        get info from  Cosmos
        call epInfoPhotoP( IncGp )
 ! 
 !       call epInfoPhitsJamXs( PhitsXs, JamXs )
